==> order-center-domain-3.0.0-CLOUD-DEV-20250916.095233-183-sources.jar: com/tydic/dyc/oc/model/payorder/sub/UocOrderShouldPay.java <==
package com.tydic.dyc.oc.model.payorder.sub;

import com.tydic.utils.generatedoc.annotation.DocField;
import lombok.Data;

import java.io.Serializable;
import java.math.BigDecimal;
import java.util.Date;
import java.util.List;

/**
 * 标题：UocOrderShouldPayDo
 * 说明：订单应付单
 * 时间：2022/4/2 14:00
 * 作者： 周中贤
 */
@Data
public class UocOrderShouldPay implements Serializable {
    private static final long serialVersionUID = 5808288523259412303L;

    @DocField(value = "应付ID")
    private Long shouldPayId;

    @DocField(value = "应付类型1：账期应付：2：预付款应付；3：成交服务费应付；4：平台使用费应付；5：到货款应付；6：验收款应付；7：质保金应付；")
    private Integer shouldPayType;

    @DocField(value = "付款方式 0:预付款 2:账期支付")
    private Integer payType;

    @DocField(value = "订单ID")
    private Long orderId;

    @DocField(value = "单据ID")
    private Long objectId;

    @DocField(value = "订单单据类型,1订单   2.销售单   3.执行单   4.发货单   5.收货单   6.售后服务单  7.支付单 8验收单  9审批单   99.其他")
    private Integer objectType;

    @DocField(value = "订单单据编码")
    private String objectNo;

    @DocField(value = "应付金额")
    private BigDecimal shouldPayAmount;

    @DocField(value = "已付金额")
    private BigDecimal paidAmount;

    @DocField(value = "退款金额")
    private BigDecimal backAmount;

    @DocField(value = "是否支付完成：0：未支付；1：支付完成")
    private Integer isPayCompleted;

    @DocField(value = "结算应付ID")
    private Long fscShouldPayId;

    @DocField(value = "应付日期")
    private Date shouldPayDate;

    @DocField(value = "付款方ID")
    private Long payerId;

    @DocField(value = "付款方名称")
    private String payerName;

    @DocField(value = "收款方ID")
    private Long payeeId;

    @DocField(value = "收款方名称")
    private String payeeName;

    @DocField(value = "合同id")
    private String contractId;

    @DocField(value = "合同编号")
    private String contractNo;

    @DocField(value = "违约金")
    private BigDecimal penalty;

    @DocField(value = "违约金比例")
    private BigDecimal penaltyRatio;

    @DocField(value = "应该推送时间")
    private Date shouldPushTime;

    @DocField(value = "实际推送时间")
    private Date actualPushTime;

    @DocField(value = "支付配置ID")
    private Long payConfId;

    @DocField(value = "支付金额类型")
    private Integer payFeeType;

    @DocField(value = "创建时间")
    private Date createTime;

    @DocField(value = "创建人")
    private String createOperName;

    @DocField(value = "创建工号")
    private String createOperId;

    @DocField(value = "更新时间")
    private Date updateTime;

    @DocField(value = "更新工号")
    private String updateOperId;

    @DocField(value = "更新人")
    private String updateOperName;

    @DocField(value = "删除标志1已删除")
    private Integer delTag;

    @DocField(value = "单据id集合")
    private List<Long> objectIdList;

    /**
     * 租户id
     */
    private Long sysTenantId;
    private String sysTenantName;
}

==> order-center-domain-3.1.0-CLOUD-DEV-20230625.084845-58-sources.jar: com/tydic/dyc/oc/model/payorder/sub/UocOrderShouldPay.java <==
package com.tydic.dyc.oc.model.payorder.sub;

import com.tydic.utils.generatedoc.annotation.DocField;
import lombok.Data;
import lombok.EqualsAndHashCode;

import java.io.Serializable;
import java.math.BigDecimal;
import java.util.Date;
import java.util.List;

/**
 * 标题：UocOrderShouldPayDo
 * 说明：订单应付单
 * 时间：2022/4/2 14:00
 * 作者： 周中贤
 */
@Data
@EqualsAndHashCode(callSuper=false)
public class UocOrderShouldPay implements Serializable {
    private static final long serialVersionUID = 5808288523259412303L;

    @DocField(value = "应付ID")
    private Long shouldPayId;

    @DocField(value = "应付类型1：账期应付：2：预付款应付；3：成交服务费应付；4：平台使用费应付；5：到货款应付；6：验收款应付；7：质保金应付；")
    private Integer shouldPayType;

    @DocField(value = "付款方式 0:预付款 2:账期支付")
    private Integer payType;

    @DocField(value = "订单ID")
    private Long orderId;

    @DocField(value = "单据ID")
    private Long objectId;

    @DocField(value = "订单单据类型,1订单   2.销售单   3.执行单   4.发货单   5.收货单   6.售后服务单  7.支付单 8验收单  9审批单   99.其他")
    private Integer objectType;

    @DocField(value = "订单单据编码")
    private String objectNo;

    @DocField(value = "应付金额")
    private BigDecimal shouldPayAmount;

    @DocField(value = "已付金额")
    private BigDecimal paidAmount;

    @DocField(value = "退款金额")
    private BigDecimal backAmount;

    @DocField(value = "是否支付完成：0：未支付；1：支付完成")
    private Integer isPayCompleted;

    @DocField(value = "结算应付ID")
    private Long fscShouldPayId;

    @DocField(value = "应付日期")
    private Date shouldPayDate;

    @DocField(value = "付款方ID")
    private Long payerId;

    @DocField(value = "付款方名称")
    private String payerName;

    @DocField(value = "收款方ID")
    private Long payeeId;

    @DocField(value = "收款方名称")
    private String payeeName;

    @DocField(value = "合同id")
    private String contractId;

    @DocField(value = "合同编号")
    private String contractNo;

    @DocField(value = "违约金")
    private BigDecimal penalty;

    @DocField(value = "违约金比例")
    private BigDecimal penaltyRatio;

    @DocField(value = "应该推送时间")
    private Date shouldPushTime;

    @DocField(value = "实际推送时间")
    private Date actualPushTime;

    @DocField(value = "支付配置ID")
    private Long payConfId;

    @DocField(value = "支付金额类型")
    private Integer payFeeType;

    @DocField(value = "创建时间")
    private Date createTime;

    @DocField(value = "创建人")
    private String createOperName;

    @DocField(value = "创建工号")
    private String createOperId;

    @DocField(value = "更新时间")
    private Date updateTime;

    @DocField(value = "更新工号")
    private String updateOperId;

    @DocField(value = "更新人")
    private String updateOperName;

    @DocField(value = "删除标志1已删除")
    private Integer delTag;

    @DocField(value = "单据id集合")
    private List<Long> objectIdList;
}
